APMFrameTiming class

Frame timing that represents an approximation of the frame's build duration.

This class stores timing information for a frame, including start and end timestamps and calculates the duration between them.

Constructors

APMFrameTiming({required DateTime startTimestamp, required DateTime endTimestamp})

Properties

duration Duration
The calculated duration of the frame.
latefinal
endTimestamp DateTime
The timestamp when the frame finished building.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp DateTime
The timestamp when the frame started building.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited